import React, { useEffect, useState, useParams } from "react";
import { Button, Space, Table, Tag, Modal, message } from "antd";
import { useStore } from "../../utils/useStore";
import { observer } from "mobx-react-lite";
import { ExclamationCircleOutlined } from "@ant-design/icons";
import { useHistory } from "react-router-dom";

export const Pulsa = observer(() => {
  const store = useStore();
  const history = useHistory();
  const [visibleModal, setVisibleModal] = useState(false);
  const [initialData, setInitialData] = useState({});
  const [confirmLoading, setConfirmLoading] = useState(false);
  const [isLoading, setIsLoading] = useState(false);
  useEffect(() => {
    const init = async () => {
      try {
        setIsLoading(true);
        await store.product.getData();
        setIsLoading(false);
      } catch (e) {
        setIsLoading(false);
      }
    };

    init();
  }, []);
  const columns = [
    {
      title: "Kode",
      dataIndex: "code",
      key: "code",
    },
    {
      title: "Produk",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "Harga Beli",
      dataIndex: "price",
      key: "price",
    },
    ,
    {
      title: "Harga Jual",
      dataIndex: "mark_up_price",
      key: "mark_up_price",
    },
    {
      title: "Gangguan",
      dataIndex: "status",
      key: "status",
      render: (text, record) => (
        <Tag
          color={record?.status === "AKTIF" ?  "processing" : "#E3E8EE" }
          style={{ color: "#4F566B" }}
        >
          {record?.status}
        </Tag>
      ),
    },
    {
      title: "Tersedia",
      dataIndex: "tersedia",
      key: "tersedia",
      render: (text, record) => (
        <Tag
          color={record?.status === "AKTIF" ?  "processing" : "#E3E8EE" }
          style={{ color: "#4F566B" }}
        >
          {record?.status === "AKTIF" ? " Ya" : "Tidak"}
        </Tag>
      ),
    },
    {
      title: "Action",
      key: "action",
      render: (text, record) => (
        <Space size="middle">
          <Button>Edit</Button>
          <Button
            onClick={async () => {
              handleDelete(record.id);
            }}
          >
            Delete
          </Button>
        </Space>
      ),
    },
  ];
  const deleteData = async (id) => {
    try {
      console.log(id);
      await store.product.delete(id);
      message.success("Data Berhasil Dihapus");
      history.push("/app/product");
    } catch (err) {
      console.log("error", err);
      message.error("Gagal menghapus");
    }
  };
  const handleDelete = (id) => {
    Modal.confirm({
      title: "Are you sure delete this record?",
      icon: <ExclamationCircleOutlined />,
      okText: "Yes",
      okType: "primary",
      cancelText: "Cancel",
      onOk() {
        return deleteData(id);
      },
      onCancel() {
        console.log("Cancel");
      },
    });
  };
  return (
    <div>
      <Table
        style={{ textAlign: "center" }}
        columns={columns}
        dataSource={store.product.data}
        bordered
      />
    </div>
  );
});
